@@ -1,4 +1,6 @@
-from base import WebSocketConsumerFilter
+from __future__ import absolute_import
+
+from .base import WebSocketConsumerFilter
 
 
 class BroadcastMessageFilter(WebSocketConsumerFilter):
