@@ -1,8 +1,10 @@
+from __future__ import absolute_import
+
 import sys
-from base import WebSocketDataFilter
+from .base import WebSocketDataFilter
 
 
-class BroadcastMessageFilter(WebSocketDataFilter):
+class StdoutRawDataFilter(WebSocketDataFilter):
 
     @classmethod
     def filter(cls, web_socket_instance, data):
